package Bot::Training::Test;

use 5.010;
use Moose;

extends 'Bot::Training::Plugin';

__PACKAGE__->meta->make_immutable;
